import { TrackingStatus, TrackingTransparencyCommon } from './common';
export { TrackingStatus };
export class TrackingTransparency extends TrackingTransparencyCommon {
    static getTrackingStatus() {
        if (parseFloat(UIDevice.currentDevice.systemVersion) >= 14) {
            return TrackingTransparency._handleStatus(ATTrackingManager.trackingAuthorizationStatus);
        }
        return TrackingStatus.Unavailable;
    }
    static _handleStatus(status) {
        switch (status) {
            case 3 /* Authorized */:
                return TrackingStatus.Authorized;
            case 2 /* Denied */:
                return TrackingStatus.Denied;
            case 1 /* Restricted */:
                return TrackingStatus.Restricted;
            case 0 /* NotDetermined */:
                return TrackingStatus.NotDetermined;
        }
    }
    static requestTrackingPermission() {
        return new Promise((resolve, reject) => {
            if (parseFloat(UIDevice.currentDevice.systemVersion) >= 14) {
                ATTrackingManager.requestTrackingAuthorizationWithCompletionHandler((status) => {
                    resolve(TrackingTransparency._handleStatus(status));
                });
            }
            else {
                resolve(TrackingStatus.Unavailable);
            }
        });
    }
}
//# sourceMappingURL=index.ios.js.map